@@ -4,12 +4,14 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_object.h"
+#include "cln/object.h"
 
 
 // Implementation.
 
-#include "cl_malloc.h"
+#include "cln/malloc.h"
+
+namespace cln {
 
 void cl_free_heap_object (cl_heap* pointer)
 {
@@ -17,7 +19,7 @@ void cl_free_heap_object (cl_heap* pointer)
 	var const cl_class* type = pointer->type;
 	if (type->destruct)
 		type->destruct(pointer);
-	cl_free_hook(pointer);
+	free_hook(pointer);
 }
 
 
@@ -31,7 +33,7 @@ void cl_free_heap_object (cl_heap* pointer)
 
 static const char * copyright_notice[] = {
   "                                                                    \n"
-  "Copyright (c) Bruno Haible 1988-1999                                \n"
+  "Copyright (c) Bruno Haible 1988-2000                                \n"
   "                                                                    \n"
   "This program is free software; you can redistribute it and/or modify\n"
   "it under the terms of the GNU General Public License as published by\n"
@@ -49,3 +51,5 @@ static const char * copyright_notice[] = {
   "                                                                    ",
   (const char *) &copyright_notice
 };
+
+}  // namespace cln
