@@ -3,6 +3,7 @@
 #ifndef _CL_LOW_H
 #define _CL_LOW_H
 
+namespace cln {
 
 // Determines the sign of a 16-bit number.
 // sign_of(wert)
@@ -1296,9 +1297,9 @@ inline uint32 mulu32_unchecked (uint32 arg1, uint32 arg2)
   // Bits von x64 zhlen: (Input x64, Output x64)
   #define logcount_64()  \
     ( /* x64 besteht aus 64 1-Bit-Zhlern (0,1).                             */\
-      x64 = (x64 & 0x5555555555555555UL) + ((x64 & 0xAAAAAAAAAAAAAAAAUL) >> 1),\
+      x64 = (x64 & 0x5555555555555555ULL) + ((x64 & 0xAAAAAAAAAAAAAAAAULL) >> 1),\
       /* x64 besteht aus 32 2-Bit-Zhlern (0,1,2).                           */\
-      x64 = (x64 & 0x3333333333333333UL) + ((x64 & 0xCCCCCCCCCCCCCCCCUL) >> 2),\
+      x64 = (x64 & 0x3333333333333333ULL) + ((x64 & 0xCCCCCCCCCCCCCCCCULL) >> 2),\
       /* x64 besteht aus 16 4-Bit-Zhlern (0,1,2,3,4).                       */\
       x64 = (uint32)(x64 + (x64 >> 32)),				       \
       /* x64 besteht aus 8 4-Bit-Zhlern (0,...,8).                          */\
@@ -1310,5 +1311,6 @@ inline uint32 mulu32_unchecked (uint32 arg1, uint32 arg2)
       /* x64 besteht aus 1 16-Bit-Zhler (0,...,64).                         */\
     )
 
+}  // namespace cln
 
 #endif /* _CL_LOW_H */
