@@ -1,6 +1,6 @@
 // Includes the CPU specific cl_asm_*.h file.
 
-#include "cl_config.h"
+#include "cln/config.h"
 #include "cl_DS_endian.h"
 
 #ifdef __m68k__
@@ -19,11 +19,11 @@
   #include "cl_asm_i386.h"
 #endif
 
-#ifdef __mips__
+#if defined(__mips__) && !defined(__mips64__) && (intDsize==32)
   #include "cl_asm_mips.h"
 #endif
 
-#ifdef __hppa__
+#if defined(__hppa__) && (intDsize==32)
   #include "cl_asm_hppa.h"
 #endif
 
